@@ -21,6 +21,7 @@
 
 const Lang = imports.lang;
 
+const Champlain = imports.gi.Champlain;
 const GLib = imports.gi.GLib;
 const Soup = imports.gi.Soup;
 
@@ -280,15 +281,19 @@ const OpenTripPlanner = new Lang.Class({
             } else if (stopIndex === 0) {
                 this._fetchWalkingRoute([points[0], stopPoint],
                                         (function(route) {
-                    stop.dist = route.distance;
+                    /* if we couldn't find an exact walking route, go with the
+                     * "as the crow flies" distance */
+                    if (route)
+                        stop.dist = route.distance;
                     this._selectBestStopRecursive(stops, index + 1, stopIndex,
-                                              callback);
+                                                  callback);
                 }).bind(this));
             } else if (stopIndex === points.length - 1) {
                 this._fetchWalkingRoute([stopPoint, points.last()], (function(route) {
-                    stop.dist = route.distance;
+                    if (route)
+                        stop.dist = route.distance;
                     this._selectBestStopRecursive(stops, index + 1, stopIndex,
-                                              callback);
+                                                  callback);
                 }).bind(this));
             } else {
                 /* for intermediate stops just return the one geographically
@@ -593,6 +598,25 @@ const OpenTripPlanner = new Lang.Class({
             this.plan.reset();
     },
 
+    /* Indicate that no routes where found, either shows the "No route found"
+     * notification, or in case of loading additional (later/earlier) results,
+     * indicate no such where found, so that the sidebar can disable the
+     * "load more" functionallity as appropriate.
+     */
+    _noRouteFound: function() {
+        if (this._extendPrevious) {
+            let message = this._query.arriveBy ?
+                          _("No earlier alternatives found.") :
+                          _("No later alternatives found.");
+            Application.notificationManager.showMessage(message);
+            this._extendPrevious = false;
+            this.plan.noMoreResults();
+        } else {
+            Application.notificationManager.showMessage(_("No route found."));
+            this._reset();
+        }
+    },
+
     _fetchRoute: function() {
         this._fetchRouters((function(success) {
             if (success) {
@@ -611,12 +635,10 @@ const OpenTripPlanner = new Lang.Class({
                         }).bind(this));
 
                         if (itineraries.length === 0) {
-                            Application.notificationManager.showMessage(_("No route found."));
                             /* don't reset query points, unlike for turn-based
                              * routing, since options and timeing might influence
                              * results */
-                            this._extendPrevious = false;
-                            this.plan.reset();
+                            this._noRouteFound();
                         } else {
                             this._recalculateItineraries(itineraries);
                         }
@@ -725,26 +747,46 @@ const OpenTripPlanner = new Lang.Class({
                 this._extendPrevious = false;
                 this.plan.update(newItineraries);
             } else {
-                Application.notificationManager.showMessage(_("No route found."));
-                this._reset();
+                this._noRouteFound();
             }
         }
     },
 
+    // create a straight-line "as the crow flies" polyline between two places
+    _createStraightPolyline: function(fromLoc, toLoc) {
+        return [new Champlain.Coordinate({ latitude: fromLoc.latitude,
+                                           longitude: fromLoc.longitude }),
+                new Champlain.Coordinate({ latitude: toLoc.latitude,
+                                           longitude: toLoc.longitude })];
+    },
+
+    /* Creates a new walking leg given start and end places, and a route
+     * obtained from GraphHopper. If the route is undefined (which happens if
+     * GraphHopper failed to obtain a walking route, approximate it with a
+     * straight line. */
     _createWalkingLeg: function(from, to, fromName, toName, route) {
         let fromLocation = from.place.location;
         let toLocation = to.place.location;
         let fromCoordinate = [fromLocation.latitude, fromLocation.longitude];
         let toCoordinate = [toLocation.latitude, toLocation.longitude];
+        let polyline = route ? route.path :
+                               this._createStraightPolyline(fromLocation, toLocation);
+        let distance = route ? route.distance :
+                               fromLocation.get_distance_from(toLocation) * 1000;
+        /* as an estimate for approximated straight-line walking legs,
+         * assume a speed of 1 m/s to allow some extra time */
+        let duration = route ? route.time / 1000 : distance;
+        let walkingInstructions = route ? route.turnPoints : null;
+
         return new TransitPlan.Leg({ fromCoordinate: fromCoordinate,
                                      toCoordinate: toCoordinate,
                                      from: fromName,
                                      to: toName,
                                      isTransit: false,
-                                     polyline: route.path,
-                                     duration: route.time / 1000,
-                                     distance: route.distance,
-                                     walkingInstructions: route.turnPoints });
+                                     polyline: polyline,
+                                     duration: duration,
+                                     distance: distance,
+                                     walkingInstructions: walkingInstructions });
     },
 
     /* fetches walking route and stores the route for the given coordinate
