@@ -52,6 +52,12 @@ const Place = new Lang.Class({
         this._internetAccess = params.internetAccess;
         delete params.internetAccess;
 
+        this._religion = params.religion;
+        delete params.religion;
+
+        this._toilets = params.toilets;
+        delete params.toilets;
+
         /* Determines if the place should be added to the place store */
         if (typeof(params.store) === 'undefined') {
             this._store = true;
@@ -158,6 +164,30 @@ const Place = new Lang.Class({
         return Translations.translateInternetAccess(this._internetAccess);
     },
 
+    set religion(v) {
+        this._religion = v;
+    },
+
+    get religion() {
+        return this._religion;
+    },
+
+    get religionTranslated() {
+        return Translations.translateReligion(this._religion);
+    },
+
+    set toilets(v) {
+        this._toilets = v;
+    },
+
+    get toilets() {
+        return this._toilets;
+    },
+
+    get toiletsTranslated() {
+        return Translations.translateYesNo(this._toilets);
+    },
+
     set wheelchair(v) {
         this._wheelchair = v;
     },
@@ -241,7 +271,9 @@ const Place = new Lang.Class({
                  wiki: this.wiki,
                  wheelchair: this.wheelchair,
                  openingHours: this.openingHours,
-                 internetAccess: this.internetAccess };
+                 internetAccess: this.internetAccess,
+                 religion: this.religion,
+                 toilets: this.toilets };
     },
 
     match: function(searchString) {
