@@ -90,6 +90,7 @@ const Plan = new Lang.Class({
     Signals: {
         'update': {},
         'reset': {},
+        'no-more-results': {},
         'itinerary-selected': { param_types: [GObject.TYPE_OBJECT] },
         'itinerary-deselected': {}
     },
@@ -120,6 +121,10 @@ const Plan = new Lang.Class({
         this.emit('reset');
     },
 
+    noMoreResults: function() {
+        this.emit('no-more-results');
+    },
+
     selectItinerary: function(itinerary) {
         this._selectedItinerary = itinerary;
         this.emit('itinerary-selected', itinerary);
